:mod:`settings` -- Setting values for `MongoLab REST API`_
----------------------------------------------------------

.. automodule:: mongolabclient.settings
    :synopsis: Setting values for MongoLab REST API
    :members:
    :undoc-members:
    :show-inheritance:

.. _MongoLab REST API: http://support.mongolab.com/entries/20433053-rest-api-for-mongodb
